==> suiviobsmer-ui-0.1.0-sources.jar: fr/ifremer/suiviobsmer/ui/data/ChartUtils.java <==
/*
 * *##% 
 * SuiviObsmer :: Web Interface
 * Copyright (C) 2009 - 2010 Ifremer
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * ##%*
 */

package fr.ifremer.suiviobsmer.ui.data;

import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Map;
import java.util.SortedMap;
import org.jfree.chart.JFreeChart;
import org.jfree.chart.axis.AxisSpace;
import org.jfree.chart.axis.CategoryAxis;
import org.jfree.chart.axis.CategoryLabelPositions;
import org.jfree.chart.axis.NumberAxis;
import org.jfree.chart.axis.ValueAxis;
import org.jfree.chart.labels.StandardCategoryItemLabelGenerator;
import org.jfree.chart.plot.CategoryPlot;
import org.jfree.chart.plot.PlotOrientation;
import org.jfree.chart.renderer.category.AbstractCategoryItemRenderer;
import org.jfree.chart.renderer.category.AreaRenderer;
import org.jfree.chart.renderer.category.BarRenderer;
import org.jfree.chart.renderer.category.LineAndShapeRenderer;
import org.jfree.data.category.DefaultCategoryDataset;
import org.jfree.ui.RectangleInsets;

/**
 * ChartUtils
 *
 * Created: 13 janv. 2010
 *
 * @author fdesbois
 * @version $Revision: 222 $
 *
 * Mise a jour: $Date: 2010-01-17 20:49:21 +0100 (dim. 17 janv. 2010) $
 * par : $Author$
 */
public class ChartUtils {

    public enum ChartType  {
        BAR(BarRenderer.class), LINE(LineAndShapeRenderer.class), AREA(AreaRenderer.class);

        protected Class<? extends AbstractCategoryItemRenderer> rendererClass;

        ChartType(Class<? extends AbstractCategoryItemRenderer> rendererClass) {
            this.rendererClass = rendererClass;
        }

        public AbstractCategoryItemRenderer createRenderer() {
            try {
                return rendererClass.newInstance();
            } catch (Exception eee) {
                // will never happens
                throw new RuntimeException(eee);
            }
        }
    }


    public static JFreeChart createCategoryChart(String title, String axisName, ChartType type,
            Map<String, SortedMap<Date, Integer>> input)  {
        DateFormat format = new SimpleDateFormat("MM/yyyy");

        DefaultCategoryDataset dataset = new DefaultCategoryDataset();

        // Fill data in dataset
        int i = 0;
        for (Map.Entry<String, SortedMap<Date, Integer>> map : input.entrySet()) {
            for (Map.Entry<Date, Integer> data : map.getValue().entrySet()) {
                dataset.setValue(data.getValue(), map.getKey(), format.format(data.getKey()));
            }
            i++;
        }

        // Axises
        CategoryAxis categoryAxis = new CategoryAxis("Mois");
        categoryAxis.setCategoryLabelPositions(CategoryLabelPositions.UP_90);
        ValueAxis valueAxis = new NumberAxis(axisName);

        // Renderer for Category
        AbstractCategoryItemRenderer renderer = type.createRenderer();
        // Show labels on each element
        renderer.setBaseItemLabelGenerator(new StandardCategoryItemLabelGenerator());
        renderer.setBaseItemLabelsVisible(Boolean.TRUE);

        CategoryPlot plot = new CategoryPlot(dataset, categoryAxis, valueAxis, renderer);
//        AxisSpace space = new AxisSpace();
//        space.setLeft(0);
//        space.setRight(0);
//        plot.setFixedRangeAxisSpace(space);
        plot.setOrientation(PlotOrientation.VERTICAL);
        plot.setAxisOffset(RectangleInsets.ZERO_INSETS);
        return new JFreeChart(title, JFreeChart.DEFAULT_TITLE_FONT, plot, true);
    }
}

==> suiviobsmer-ui-0.3.0-sources.jar: fr/ifremer/suiviobsmer/ui/data/ChartUtils.java <==
/*
 * *##% 
 * SuiviObsmer :: Web Interface
 * Copyright (C) 2009 - 2010 Ifremer
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * ##%*
 */

package fr.ifremer.suiviobsmer.ui.data;

import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Map;
import java.util.SortedMap;
import org.jfree.chart.JFreeChart;
import org.jfree.chart.axis.AxisSpace;
import org.jfree.chart.axis.CategoryAxis;
import org.jfree.chart.axis.CategoryLabelPositions;
import org.jfree.chart.axis.NumberAxis;
import org.jfree.chart.axis.ValueAxis;
import org.jfree.chart.labels.StandardCategoryItemLabelGenerator;
import org.jfree.chart.plot.CategoryPlot;
import org.jfree.chart.plot.PlotOrientation;
import org.jfree.chart.renderer.category.AbstractCategoryItemRenderer;
import org.jfree.chart.renderer.category.AreaRenderer;
import org.jfree.chart.renderer.category.BarRenderer;
import org.jfree.chart.renderer.category.LineAndShapeRenderer;
import org.jfree.data.category.DefaultCategoryDataset;
import org.jfree.ui.RectangleInsets;

/**
 * ChartUtils
 *
 * Created: 13 janv. 2010
 *
 * @author fdesbois
 * @version $Revision: 236 $
 *
 * Mise a jour: $Date: 2010-01-18 18:13:43 +0100 (lun., 18 janv. 2010) $
 * par : $Author$
 */
public class ChartUtils {

    public enum ChartType  {
        BAR(BarRenderer.class, false), LINE(LineAndShapeRenderer.class, true), AREA(AreaRenderer.class, true);

        protected Class<? extends AbstractCategoryItemRenderer> rendererClass;

        protected boolean noCategoryMargin;

        ChartType(Class<? extends AbstractCategoryItemRenderer> rendererClass, boolean noCategoryMargin) {
            this.rendererClass = rendererClass;
            this.noCategoryMargin = noCategoryMargin;
        }

        public AbstractCategoryItemRenderer createRenderer() {
            try {
                return rendererClass.newInstance();
            } catch (Exception eee) {
                // will never happens
                throw new RuntimeException(eee);
            }
        }
    }


    public static JFreeChart createCategoryChart(String title, String axisName, ChartType type,
            Map<String, SortedMap<Date, Integer>> input)  {
        DateFormat format = new SimpleDateFormat("MM/yyyy");

        DefaultCategoryDataset dataset = new DefaultCategoryDataset();

        // Fill data in dataset
        int i = 0;
        for (Map.Entry<String, SortedMap<Date, Integer>> map : input.entrySet()) {
            for (Map.Entry<Date, Integer> data : map.getValue().entrySet()) {
                dataset.setValue(data.getValue(), map.getKey(), format.format(data.getKey()));
            }
            i++;
        }

        // Axises
        CategoryAxis categoryAxis = new CategoryAxis("Mois");
        categoryAxis.setCategoryLabelPositions(CategoryLabelPositions.UP_90);
        if (type.noCategoryMargin) {
            categoryAxis.setCategoryMargin(0);
        }
        ValueAxis valueAxis = new NumberAxis(axisName);
        valueAxis.setUpperMargin(0.15);

        // Renderer for Category
        AbstractCategoryItemRenderer renderer = type.createRenderer();
        // Show labels on each element
        renderer.setBaseItemLabelGenerator(new StandardCategoryItemLabelGenerator());
        renderer.setBaseItemLabelsVisible(Boolean.TRUE);

        CategoryPlot plot = new CategoryPlot(dataset, categoryAxis, valueAxis, renderer);
        plot.setOrientation(PlotOrientation.VERTICAL);
        plot.setAxisOffset(RectangleInsets.ZERO_INSETS);
        return new JFreeChart(title, JFreeChart.DEFAULT_TITLE_FONT, plot, true);
    }
}
